from .pysed import main

from .pysed import __version__
from .pysed import __license__
from .pysed import __email__
